summaryrefslogtreecommitdiffstats
path: root/libkdepim/infoextension.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/infoextension.h')
-rw-r--r--libkdepim/infoextension.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/libkdepim/infoextension.h b/libkdepim/infoextension.h
index 0a992a154..343f71720 100644
--- a/libkdepim/infoextension.h
+++ b/libkdepim/infoextension.h
@@ -35,18 +35,19 @@ namespace KParts
/**
* Provides a way to get information out of a PIM-Part
**/
- class KDE_EXPORT InfoExtension : public QObject
+ class KDE_EXPORT InfoExtension : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constucts an InfoExtension.
*
* @param parent The parent widget.
* @param name The name of the class.
**/
- InfoExtension( KParts::ReadOnlyPart *parent, const char* name);
+ InfoExtension( KParts::ReadOnlyPart *tqparent, const char* name);
~InfoExtension();
private:
@@ -35,18 +35,19 @@ namespace KParts
* Constucts an InfoExtension.
*
- * @param parent The parent widget.
+ * @param tqparent The tqparent widget.
* @param name The name of the class.
**/